@@ -12,15 +12,16 @@ The main entry point for RPC4Django. Usually, the user simply puts
 '''
 
 import logging
+import json
 from xml.dom.minidom import parseString
 from xml.parsers.expat import ExpatError
 from django.http import HttpResponse, Http404, HttpResponseForbidden
 from django.shortcuts import render_to_response
 from django.conf import settings
 from django.core.urlresolvers import reverse, NoReverseMatch, get_mod_func
+from django.views.decorators.csrf import csrf_exempt
 from django.utils.importlib import import_module
 from rpcdispatcher import RPCDispatcher
-from jsonrpcdispatcher import json
 from __init__ import version
 
 logger = logging.getLogger('rpc4django')
@@ -142,6 +143,7 @@ def is_xmlrpc_request(request):
 
     return False
 
+@csrf_exempt
 def serve_rpc_request(request):
     '''
     Handles rpc calls based on the content type of the request or
@@ -230,20 +232,6 @@ def serve_rpc_request(request):
                                   template_data,
                                   context_instance=RequestContext(request))
 
-# exclude from the CSRF framework because RPC is intended to be used cross site
-try:
-    # Django 1.2
-    from django.views.decorators.csrf import csrf_exempt
-except ImportError:
-    try:
-        # Django 1.1
-        from django.contrib.csrf.middleware import csrf_exempt
-    except ImportError:
-        # Django 1.0
-        csrf_exempt = None
-
-if csrf_exempt is not None:
-    serve_rpc_request = csrf_exempt(serve_rpc_request)
 
 # reverse the method for use with system.describe and ajax
 try:
@@ -259,12 +247,7 @@ else:
     json_encoder = JSON_ENCODER
 
 
-if not issubclass(json_encoder, json.JSONEncoder):
-    raise Exception("RPC4DJANGO_JSON_ENCODER must be derived from "
-                    "rpc4django.jsonrpcdispatcher.JSONEncoder")
-
 # instantiate the rpcdispatcher -- this examines the INSTALLED_APPS
 # for any @rpcmethod decorators and adds them to the callable methods
 dispatcher = RPCDispatcher(URL, APPS, RESTRICT_INTROSPECTION,
         RESTRICT_OOTB_AUTH, json_encoder)
-
